@@ -190,7 +190,9 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 		         (u'nn',u'(.*n)nAr',u'piennar'),
 		         (u'mm',u'(.*m)mel',u'ommel'),
 		         (u'ng',u'(.*n)ger',u'penger'),
-		         (u'v',u'(.*)vAl',u'taival')]),
+		         (u'd',u'(.*)dAr',u'udar'),
+		         (u'v',u'(.*)vAl',u'taival'),
+		         (u'>k',u'(.*)en',u'säen')]),
 	(u'rosé', u'-', [(None,u'(.*V)',u'rosé')]),
 	(u'parfait', u'-', [(None,u'(.*VC)',u'parfait')]),
 	(u'huuli', u'-', [(None,u'(.*C)i',u'tuohi')]),
@@ -300,14 +302,19 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			    (u'tt',u'(.*V)ttAA',u'ammottaa')]),
 	(u'loistaa', u'-', [(None,u'(.*C)AA',u'loistaa')]),
 	(u'vuotaa', u'sw', [(u'lt',u'(.*Vl)tAA',u'puoltaa'),
+			(u'rt',u'(.*Vr)tAA',u'juurtaa'),
+			(u'nt',u'(.*Vn)tAA',u'saksantaa'),
 			(u't',u'(.*V)tAA',u'vuotaa')]),
 	(u'huutaa', u'sw', [(u'nt',u'(.*Vn)tAA',u'huutaa'),
 			(u't',u'(.*V)tAA',u'huutaa')]),
 	(u'sukeltaa', u'sw', [(u'lt',u'(.*Vl)tAA',u'sukeltaa'),
-			  (u'rt',u'(.*Vr)tAA',u'musertaa')]),
-	(u'paleltaa', u'sw', [(u'lt',u'(.*Vl)tAA',u'paleltaa')]),
+			  (u'rt',u'(.*Vr)tAA',u'musertaa'),
+			  (u'nt',u'(.*Vn)tAA',u'jäykentää')]),
+	(u'paleltaa', u'sw', [(u'lt',u'(.*Vl)tAA',u'paleltaa'),
+			  (u'nt',u'(.*Vn)tAA',u'nuotintaa')]),
 	(u'murtaa', u'sw', [(u'rt',u'(.*Vr)tAA',u'murtaa')]),
-	(u'juontaa', u'sw', [(u'nt',u'(.*Vn)tAA',u'juontaa')]),
+	(u'juontaa', u'sw', [(u'nt',u'(.*Vn)tAA',u'juontaa'),
+			 (u'rt',u'(.*Vr)tAA',u'pyörtää')]),
 	(u'pahentaa', u'sw', [(u'nt',u'(.*Vn)tAA',u'pahentaa')]),
 	(u'kaivaa', u'sw', [(None,u'(.*C)AA',u'kaivaa'),
 	                    (u'nt',u'(.*n)tAA',u'antaa'),
@@ -349,6 +356,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			   (None,u'(.*CA)istA',u'nuolaista'),
 			   (None,u'(.*C)istA',u'kalista'),
 			   (None,u'(.*s)tA',u'nousta'),
+			   (u'v',u'(.*)vistA',u'vavista'),
 			   (u'ng',u'(.*n)gAistA',u'rangaista')]),
 	(u'mennä', u'-', [(None,u'(.*n)nA',u'mennä')]),
 	(u'katsella', u'ws', [(None,u'(.*el)lA',u'katsella'),
