@@ -20,6 +20,7 @@
 
 # This code is heavily based on code written by Harri Pitkänen.
 
+import codecs
 import generate_lex_common
 import hfconv
 import voikkoutils
@@ -27,34 +28,33 @@ import re
 import sys
 
 # Historical inflections in alphabetical order.
-historical = [(u'aavistaa', u'sw', [(u'tt',u'(.*O)ittAA',u'kirjoittaa'),
-				    (u'tt',u'(.*O)ttAA',u'ammottaa'),
-				    (None,u'(.*t)AA',u'aavistaa'),
-				    (u'tt',u'(.*[AeiU]t)tAA',u'alittaa'),
-				    (u't',u'(.*h)tAA',u'astahtaa')]),
-	      (u'arvailla',   u'-',  [(None,u'(.*[AOU]])illA',u'arvailla')]),
-	      (u'hohtaa',     u'sw', [(u'tt',u'(.*t)tAA',u'heittää')]),
-	      (u'iäkäs',      u'ws', [(u'k',u'(.*k)As',u'iäkäs')]),
-	      (u'katsella',   u'ws', [(None,u'(.*[AOU])illA',u'arvailla')]),
-	      (u'kaivaa',     u'sw', [(None,u'(.*aj)AA',u'ajaa')]),
-	      (u'kirjoittaa', u'sw', [(u'tt',u'(.*O)ittAA',u'kirjoittaa'),
-				      (u'tt',u'(.*O)ttAA',u'ammottaa'),
-				      (u'tt',u'(.*[AeiU]t)tAA',u'asettaa')]),
-	      (u'kuollut', u'-', [(None,u'(.*neits)yt',u'neitsyt'),
-				  (None,u'(.*C)lUt',u'kuollut'),
-				  (None,u'(.*)nUt', u'punonut'),
-				  (None,u'(.*C)rUt',u'purrut'),
-				  (None,u'(.*C)sUt',u'juossut')]),
-	      (u'onneton', u'ws', [(None,u'(.*)tOn',u'alaston'),
-				   (u't',u'(.*)tOn',u'onneton')]),
-	      (u'punoa',   u'sw', [(u't',u'(...*AU)tUA',u'antautua')]),
-##	      (u'vieras',  u'ws', [(u'k',u'(.*k)As',u'iäkäs'),
-##				   (None,u'(.*[lr]iA)s',u'utelias'),
-##				   (u'>k',u'(.*)As',u'vilkas')]),
+historical = [
+	(u'aavistaa', u'sw', [(u'tt',u'(.*O)ittAA',u'kirjoittaa'),
+			      (u'tt',u'(.*O)ttAA',u'ammottaa'),
+			      (None,u'(.*t)AA',u'aavistaa'),
+			      (u'tt',u'(.*[AeiU]t)tAA',u'alittaa'),
+			      (u't',u'(.*h)tAA',u'astahtaa')]),
 	(u'ahven',    u'ws', [(None,u'(.*CVC)',u'ahven')]),
-        (u'antautua', u'sw', [(u't',u'(.*)tUA',u'antautua')]),
 	(u'altis',    u'ws', [(None, u'(.*t)is', u'altis')]),
-        (u'banaali',  u'sw', [(None,u'(.*)i',u'banaali'),
+	(u'antautua', u'sw', [(u't',u'(.*)tUA',u'antautua')]),
+	(u'arvailla',   u'-',  [(None,u'(.*[AOU]])illA',u'arvailla')]),
+	(u'arvelu',   u'sw', [(None,u'(.*e)istO',u'aarteisto')]),
+	(u'autio', u'-', [(None,u'(..*C)aatio',u'obligaatio'),
+			  (None,u'(..*C)uutio',u'resoluutio'),
+			  (None,u'(..*C)uusio',u'illuusio'),
+			  (None,u'(..*C)itio',u'traditio'),
+			  (None,u'(.*)ktio',u'funktio'),
+			  (None,u'(.*)',u'autio')]),
+        (u'banaali',  u'sw', [(None,u'(..*[^aeouyäö]o)di',u'symboli_di'),
+			      (None,u'(..*[^aeouyäö]o)fi',u'symboli_fi'),
+			      (None,u'(..*[^aeouyäö]o)gi',u'symboli_gi'),
+			      (None,u'(..*[^aeouyäö]o)li',u'symboli_li'),
+			      (None,u'(..*[^aeouyäö]o)mi',u'symboli_mi'),
+			      (None,u'(..*[^aeouyäö]o)ni',u'symboli_ni'),
+			      (None,u'(..*[^aeouyäö]o)ri',u'symboli_ri'),
+			      (None,u'(..*[^aeouyäö]o)vi',u'symboli_vi'),
+			      (None,u'(..*a)di',u'balladi'),
+			      (None,u'(.*)i',u'banaali'),
                               (u'nt',u'(.*n)ti',u'hollanti'),
 			      (u'nk',u'(.*n)ki',u'killinki'),
 			      (u'kk',u'(.*k)ki',u'kajakki'),
@@ -63,28 +63,90 @@ historical = [(u'aavistaa', u'sw', [(u'tt',u'(.*O)ittAA',u'kirjoittaa'),
 			      (u't',u'(.*)ti',u'konvehti') ]),
         (u'bébé', u'-', [(None,u'(.*V)',u'bébé')]),
         (u'haastaa', u'sw', [(None,u'(.*C)AA',u'haastaa')]),
+	(u'hohtaa',  u'sw', [(u'tt',u'(.*t)tAA',u'heittää')]),
+	(u'huutaa', u'sw', [(u'nt',u'(.*Vn)tAA',u'alentaa'),
+			(u't',u'(.*V)tAA',u'huutaa')]),
+	(u'iäkäs',   u'ws', [(u'k',u'(.*[mntv]e)ikAs',u'maineikas'),
+			     (u'k',u'(.*k)As',u'iäkäs')]),
         (u'kaihtaa', u'sw', [(u't',u'(.*)tAA',u'kaihtaa')]),
-        (u'kantaja', u'-', [(None,u'(.*)jA',u'johdin_jA_kantaja')]),
+	(u'kaivaa',     u'sw', [(None,u'(.*aj)AA',u'ajaa')]),
+        (u'kantaja', u'-', [(None,u'(.*)jA',u'kantaja')]),
+	(u'katsella',   u'ws', [(None,u'(.*[AOU])illA',u'arvailla')]),
         (u'kirjoitella', u'ws', [(None,u'(...*O)itellA',u'kilvoitella'),
                                  (None,u'(.*O)tellA',u'ilotella')]),
-	(u'tulla', u'ws', [(None,u'(.*Vl)lA',u'tulla')]),
+        (u'kirjoittaa', u'sw', [(u'tt',u'(.*O)ittAA',u'kirjoittaa'),
+				(u'tt',u'(.*O)ttAA',u'ammottaa'),
+				(u'tt',u'(.*[AeiU]t)tAA',u'asettaa')]),
+        (u'karahka', u'-', [(None,u'(.*lo)gia',u'analogia'),
+			    (None,u'(.*so)fia',u'filosofia'),
+			    (None,u'(.*gra)fia',u'topografia')]),
         (u'koiras', u'ws', [(None,u'(.*A)s',u'koiras')]),
+	(u'kulkija', u'-', [(None,u'(.*lo)gia',u'analogia'),
+			    (None,u'(.*so)fia',u'filosofia'),
+			    (None,u'(.*gra)fia',u'topografia')]),
+        (u'kuollut', u'-', [(None,u'(.*neits)yt',u'neitsyt'),
+			    (None,u'(.*C)lUt',u'kuollut'),
+			    (None,u'(.*)nUt', u'punonut'),
+			    (None,u'(.*C)rUt',u'purrut'),
+			    (None,u'(.*C)sUt',u'juossut')]),
 	(u'kutiaa', u'-',  [(None,u'(.*Cia)a',u'kutiaa')]),
         (u'laittaa', u'sw', [(u'tt',u'(.*t)tAA',u'laittaa')]),
+	(u'lampi', u'-',   [(None,u'(.*kam)pi',u'lampi')]),
+	(u'nainen', u'-', [(None,u'(.*Co)rinen',u'allegorinen'),
+			   (None,u'(.*Co)finen',u'filosofinen'),
+			   (None,u'(.*Co)ginen',u'psykologinen'),
+			   (None,u'(.*Co)ninen',u'ironinen'),
+			   (None,u'(.*gra)finen',u'topografinen'),
+			   (None,u'(.*(?:aa|ee|ii|oo|uu|yy|ää|öö)p)pinen',u'eeppinen'),
+			   (None,u'(.*(?:aa|ee|ii|oo|uu|yy|ää|öö)t)tinen',u'kriittinen'),
+			   (None,u'(.*(?:aa|ee|ii|oo|uu|yy|ää|öö)k)kinen',u'psyykkinen'),
+			   (None,u'(.*[ts]i)ivinen',u'relatiivinen'),  # Myös massi(i)vinen yms.
+			   (None,u'(.*)nen',u'nainen')]),
 	(u'neiti', u'sw', [(u't',u'(.*)ti',u'neiti')]),
         (u'nuori', u'-', [(None,u'(.*C)i',u'nuori')]),
+	(u'onneton', u'ws', [(None,u'(.*)tOn',u'alaston'),
+			     (u't',u'(.*)tOn',u'onneton')]),
         (u'paahtaa', u'sw', [(u't',u'(.*)tAA',u'paahtaa')]),
         (u'paistaa', u'sw', [(None,u'(.*C)AA',u'paistaa')]),
         (u'palata', u'ws', [(None,u'(.*)AtA',u'palata')]),
         (u'palaa', u'ws', [(None,u'(.*C)AA',u'palaa')]),
+        (u'paperi',  u'sw', [(None,u'(..*[^aeouyäö]o)di',u'symboli_di'),
+			     (None,u'(..*[^aeouyäö]o)fi',u'symboli_fi'),
+			     (None,u'(..*[^aeouyäö]o)gi',u'symboli_gi'),
+			     (None,u'(..*[^aeouyäö]o)li',u'symboli_li'),
+			     (None,u'(..*[^aeouyäö]o)mi',u'symboli_mi'),
+			     (None,u'(..*[^aeouyäö]o)ni',u'symboli_ni'),
+			     (None,u'(..*[^aeouyäö]o)ri',u'symboli_ri'),
+			     (None,u'(..*[^aeouyäö]o)vi',u'symboli_vi'),
+			     (None,u'(..*a)di',u'balladi')]),
         (u'pasuuna', u'sw', [(None,u'(.*)A',u'pasuuna')]),
+	(u'punoa',   u'sw', [(u't',u'(...*AU)tUA',u'antautua')]),
+        (u'risti',   u'sw', [(None,u'(..*[^aeouyäö]o)di',u'telefoni_di'),
+			     (None,u'(..*[^aeouyäö]o)fi',u'telefoni_fi'),
+			     (None,u'(..*[^aeouyäö]o)gi',u'telefoni_gi'),
+			     (None,u'(..*[^aeouyäö]o)li',u'telefoni_li'),
+			     (None,u'(..*[^aeouyäö]o)mi',u'telefoni_mi'),
+			     (None,u'(..*[^aeouyäö]o)ni',u'telefoni_ni'),
+			     (None,u'(..*[^aeouyäö]o)ri',u'telefoni_ri'),
+			     (None,u'(..*[^aeouyäö]o)vi',u'telefoni_vi'),
+		             (None,u'(..*gr)afi',u'biografi'),
+			     (None,u'(..*)adi',u'marinadi'),
+			     (None,u'(..*)idi',u'pyramidi')]),
         (u'siivota', u'ws', [(None,u'(.*O)tA',u'siivota')]),
 	(u'sydän', u'-', [(None,u'(.*A)n',u'sydän')]),
         (u'taittaa', u'sw', [(u'tt',u'(.*t)tAA',u'taittaa')]),
+	(u'tulla', u'ws', [(None,u'(.*Vl)lA',u'tulla')]),
         (u'tuomi', u'-', [(None,u'(.*V)mi',u'tuomi')]),
 	(u'uros', u'-', [(None,u'(.*)s',u'uros')]),
+	(u'terve', u'-',[(None,u'(.*)',u'terve')]),
 	(u'valmis',u'ws', [(None,u'(.*)is',u'valmis')]),
+	(u'vastaus', u'-', [(None,u'(..[^oö]*O)itUs',u'aivoitus'),
+			    (None,u'(..[^oö]*O)tUs',u'jaotus'),
+			    (None,u'(.*V)s',u'vastaus'),]),
 	(u'veranta', u'sw', [(u'nt',u'(.*n)tA',u'veranta')]),
+	(u'vieras',  u'ws', [(None,u'(.*[lr]iA)s',u'utelias'),
+			     (u'k',u'(.*mek)As',u'iäkäs'),
+			     (u'k',u'(.*k)As',u'varas')]),
 	(u'vihanta', u'sw', [(u'nt',u'(.*n)tA',u'vihanta')]),
         (u'virkkaa', u'sw', [(u'kk',u'(.*k)kAA',u'jakaa')])
         ]
@@ -92,30 +154,13 @@ historical = [(u'aavistaa', u'sw', [(u'tt',u'(.*O)ittAA',u'kirjoittaa'),
 classmap = historical
 classmap.extend(hfconv.modern_classmap)
 
+#          u"(?P<jaotus>OtUs)|" + \
+#          u"(?P<aivoitus>OitUs)|" + \
+#
+
 pattern = u"^(?P<alku>.*)(?:" + \
-          u"(?P<ammottaa>OttAA)|" + \
-          u"(?P<kirjoittaa>OittAA)|" + \
-          u"(?P<jaotus>OtUs)|" + \
-          u"(?P<aivoitus>OitUs)|" + \
-          u"(?P<nuolaista>AistA)|" + \
-          u"(?P<utelias_ankerias>[lr]iAs)|" + \
-          u"(?P<obligaatio>Caatio)|" + \
-          u"(?P<resoluutio>Cuutio)|" + \
-          u"(?P<illuusio>Cuusio)|" + \
-          u"(?P<traditio>Citio)|" + \
-	  u"(?P<funktio>.ktio)|" + \
-	  u"(?P<symboli_ym>[^aeouyäö]o[dfglmnrv]i)|" + \
-	  u"(?P<balladi>..adi)|" + \
-	  u"(?P<logia_ym>gogia|logia|sofia)|" + \
-	  u"(?P<loginen_ym>goginen|loginen|sofinen)|" + \
-	  u"(?P<grafia>grafia)|" + \
-	  u"(?P<grafinen>.grafinen)|" + \
-	  u"(?P<ironinen_ym>Co[nr]inen)|" + \
-	  u"(?P<psyykkinen_ym>(?:aa|ee|ii|oo|uu|yy|ää|öö)(?:kk|pp|tt)inen)|" + \
-	  u"(?P<relatiivinen>tiivinen)|" + \
-	  u"(?P<aarteisto>eistO)|" + \
 	  u"(?P<keltainen>C[aouyäö]i?nen)|" + \
-	  u"(?P<antautua>CAUtUA)|" + \
+	  u"(?P<symboli_ym>[^aeouyäö]o[dfglmnrv]i)|" + \
 	  u"(?P<maineikas>[mntv]eikAs)" + \
           u")$"
 
@@ -134,8 +179,10 @@ rx_end = re.compile(end, re.IGNORECASE)
 
 #print pattern
 
+
 # Sanat, jotka tunnistetaan Sukija-versiossa automaagisesti toisten
-# sanojen johdoksina.
+# sanojen johdoksina. Tällaiset sanat pitäisi merkitä Joukahaisen
+# sanastoon lipulla ei kuulu indeksointisanastoon.
 #
 # Niiden lisäksi Sukijassa ei tarvita erisnimiä, jotka ovat myös
 # yleisnimiä. Kuitenkin mukaan pitää ottaa sellaiset sanat, jotka
@@ -145,94 +192,18 @@ rx_end = re.compile(end, re.IGNORECASE)
 # Sanaluettelon saa näin:
 # grep '<form>' ../*/*xml | sed -e "s@</\?form>@@g" | sort
 #
-#        Sukija-versiossa "amerikan" on etuliite. (-:
-#u"punanen", u"päivänen",
-words = [
-	 u"aikalainen", u"alaisuus", u"alastulo",
-	 u"allekirjoittaa", u"alleviivata",
-	 u"amerikanenglanti", u"amerikanenglantilainen", u"amerikanjuutalainen",
-         u"amerikanrauta", u"amerikansalaatti", u"amerikansuomalainen", u"amerikansuomi",
-         u"ammattilainen", u"arastella",
-         u"edellisvuotinen", u"elämä", u"esilletuominen", u"esilletuonti",
-	 u"esimerkki", u"etruskilainen",
-         u"freudilainen",
-	 u"halpatyö", u"hautaus", u"herraskartano", u"herrasmies", u"herraspoika",
-	 u"herrasväki",
-	 u'huiskauttaa', u"hyvinvoida", u"hyvinvointi",
-	 u"innoittua", u"institutionalisoitua", u"itkettynyt", u"itkettyä",
-	 u"julkishallinto", u"julkissektori", u"julkistalous",
-	 u"jumalaistaru", u"jumalaistarusto", u"jälkeenjäänyt",
-	 u"kansalainen", u"kansallismielinen", u"kestitys", u"kumous", u"kuntalainen",
-	 u"kuolleenkoura", u"kuolleenmiehenkytkin",
-	 u"kurssilainen", u"kymmenvuotinen", u"kyyhkyläinen",
-	 u"käsinkylvö", u"käsinpesu", u"käsinlypsy", u"käsinkohonta",
-	 u"käsinladonta", u"käsinlajittelu", u"käsinlatoja", u"käsinohjaus",
-	 u"käsinseisonta", u"käsinkäynti",
-	 u"käynti", u"käytävä",
-	 u"laajakaista", u"laajakangas", u"laajakulma", u"laajakuva",
-	 u"laakafilmi", u"laakalyönti", u"laakapaino", u"laakapihti",
-	 u"lahkolainen", u"lahopuu",
-	 u"lahtelainen", u"laulattaa", u"leniniläinen", u"liittolainen", u"lojaalisuus",
-	 u"luokkalainen", u"luontoistalous", u"lyhytvalinta", u"lyönti",
-	 u"maailmanympärimatka",
-	 u"maallistua", u"maattojohdin", u"maattojohto", u"maolainen",
-	 u"marxilainen", u"marksismi-leninismi", u"marxismi-leninismi",
-	 u"metsäläinen", u"mierolainen",
-	 u"mikkelinpäivä", u"mittatarkka", u"mongolilainen", u"mäkitupalainen",
-	 u"naarmuttua", u"nimismies",
-	 u"ohutsuoli", u"oikeanlainen", u"oikeistolainen", u"oikeus",
-	 u"omanlainen", u"opetus", u"otto",
-         u"pakolainen", u"peräänajo", u"pito", u"poltto",
-	 u"rivittyä", u"romahdusmainen", u"ruskettua", u"rusketus",
-	 u"siirtolainen", u"sisäpiiriläinen", u"sisäänajo", u"sisäänmeno",
-	 u"sisääntulo", u"strippaus", u"säteisliike", u"sätkytellä",
-	 u"takaisinkytkentä",
-	 u"tietynlainen", u"trotskilainen", u"tuonti", u"tupalainen", u"työläinen",
-	 u"täysihoito", u"täysihoitola",
-	 u"uloskäytävä", u"uurteisvalas",
-	 u"vaivaisenluu", u"vajaamielinen", u"valmistuttaa",
-	 u"valmisateria", u"valmisbetoni", u"valmismatka", u"valmisosa",
-	 u"valmispakkaus", u"valmisruoka", u"valmistalo", u"valmistuote", u"valmisvaate",
-	 u"vasemmistolainen", u"vastaavanlainen", u"veto",
-	 u"voima", u"wrightiläinen", u"väärinkäsitys",
-	 u"vähittäishinta", u"vähittäiskauppa", u"vähittäismaksu", u"vähittäismyymälä",
-         u"vähittäismyynti",
-	 u"ylösnoussut", u"yritellä", u"ystävällismielinen",
-	 u"Aaltonen", u"Aamu", u"Aarnio", u"Aho", u"Alanko", u"Alkio", u"Arabia",
-	 u"Armenia", u"Aro", u"Astuvansalmi", u"Asukas", u"Aura", u"Aurinko", u"Autio",
-	 u"Bulgaria",
-	 u"Eesti", u"Elo", u"Englanti", u"Eno", u"Espanja", u"Esteri",
-	 u"Georgia", u"Guinea",
-	 u"Hamina", u"Hanko", u"Helo", u"Hollanti", u"Hovi", u"Huhta", u"Hukka", u"Härmä",
-	 u"Ilma", u"Ilta", u"Islanti", u"Italia",
-	 u"Jalo", u"Jylhä", u"Järvi",
-	 u"Kallio", u"Kangas", u"Kannus", u"Kanttura", u"Karjala", u"Karjalainen", u"Kari",
-         u"Kartano", u"Kartio", u"Kaste",
-	 u"Kerttu", u"Kerttunen", u"Kielo", u"Kiina", u"Kilpi", u"Kisko", u"Knuutinpoika",
-         u"Koitto", u"Koivisto", u"Koivu", u"Kokkari", u"Kolari", u"Kotka", u"Koppelo",
-	 u"Koski", u"Kreikka", u"Kroatia", u"Kuha", u"Kuikka", u"Kukka", u"Kulho",
-	 u"Kuokka", u"Kurki", u"Kurppa", u"Kuru", u"Kuutti", u"Kytö", u"Kärkistensalmi",
-	 u"Laakso", u"Lahja", u"Lahti", u"Laina", u"Laine", u"Lappi", u"Lauha",
-	 u"Lehto", u"Lemu", u"Lilja", u"Lintunen", u"Liperi", u"Lotta",
-	 u"Maa", u"Maila", u"Malmi", u"Marja", u"Martta", u"Matti", u"Mela", u"Metso", u"Miina",
-	 u"Minttu", u"Missi", u"Moisio", u"Muikku", u"Murto", u"Mäkinen",
-	 u"Niemi", u"Niva", u"Norja",
-	 u"Oiva", u"Orvokki", u"Otto",
-	 u"Pajari", u"Palmu", u"Paula", u"Perho", u"Pinja",
-	 u"Pohja", u"Pokka", u"Portugali", u"Posti", u"Puola", u"Päivä",
-	 u"Raitio", u"Ranta", u"Ranska", u"Rauha", u"Rautio", u"Rautu", u"Reima", u"Riski",
-	 u"Ruotsi", u"Ruukki", u"Ruusu", u"Rönkkö",
-	 u"Saari", u"Saksa", u"Saku", u"Salo", u"Satu", u"Savikko", u"Seppä",
-	 u"Siimes", u"Sikiö", u"Sini", u"Sirkka", u"Sisko",
-	 u"Somero", u"Sorsa", u"Sulo", u"Suomi", u"Säde", u"Säteri",
-	 u"Taimi", u"Taisto", u"Tallus", u"Tanska", u"Tapani", u"Tarkka", u"Tarmo",
-	 u"Terho", u"Terttu", u"Tiibet", u"Tikka", u"Timpuri", u"Toivo",
-         u"Tšekki", u"Tuisku", u"Turkki", u"Tuuli",
-	 u"Ukraina", u"Unelma", u"Unkari",
-	 u"Valta", u"Valtti", u"Varis", u"Varkaus", u"Varma", u"Vasara", u"Vento",
-         u"Venäjä", u"Venäläinen", u"Vesa", u"Vieno", u"Vietnam", u"Viita", u"Viro", u"Virolainen",
-	 u"Virta", u"Visa", u"Vuokko", u"Vuoksi",
-	 u"Ylämaa"]
+words = []
+inputfile = codecs.open ('sukija/ei-sukija.txt', 'r', 'UTF-8')
+while True:
+	word = inputfile.readline()
+	if (len(word) == 0):
+		break
+	if (word[0] == '#'):
+		continue;
+	word = word[:-1]      # Poistetaan \n sanan lopusta.
+#	print (word)
+	words.append (word)
+
 
 # Aksentilliset kirjaimet UTF-8 -merkistössä 0000-017F,
 # ei kuitenkaan merkkejä š ja ž.
@@ -413,7 +384,6 @@ def new_vtype (malaga_vtype, wordform):
 		return u"aä"
 	else:
 	       	return malaga_vtype
-	
 
 def handle_word(main_vocabulary,vocabulary_files,word):
 	if generate_lex_common.has_flag(word, "not_sukija"): return
@@ -457,7 +427,7 @@ def handle_word(main_vocabulary,vocabulary_files,word):
 #		print (u"Hoo " + str(voikko_infclass) + u" " + u" " + wordform + u"\n")
 #		print(u"Tavutus1 " + wordform + u" " + hyphenate(wordform.lower()) + u"\n")
 		(alku, jatko) = generate_lex_common.get_malaga_inflection_class(wordform, voikko_infclass, wordclasses, classmap)
-#		print (u"Huu " + wordform + u" " + str(alku) + u" " + str(jatko) + u" "  + str(voikko_infclass) + u"\n")
+#		print (u"Huu " + wordform + u" " + str(alku) + u" " + str(jatko) + u" "  + str(voikko_infclass))
 		if forced_inflection_vtype == voikkoutils.VOWEL_DEFAULT:
 			vtype = voikkoutils.get_wordform_infl_vowel_type(altform)
 		else: vtype = forced_inflection_vtype
@@ -480,7 +450,8 @@ def handle_word(main_vocabulary,vocabulary_files,word):
 		if (rx_end.match(wordform) != None):
 #			print ("Ei tarvita: " + wordform)
 			continue
-		if ((wordform == u"ori") and (jatko == u"risti")):
+		if (((wordform == u"ori")   and (jatko == u"risti")) or
+		    ((wordform == u'kampi') and (jatko == u'sampi'))):
 #			print ("Ei tarvita: " + wordform)
 			continue
 		
@@ -527,192 +498,19 @@ def handle_word(main_vocabulary,vocabulary_files,word):
 				alku2 = alku + u"i"  # Hevonen => hevoinen.
 			jatko2 = jatko
 			wordform2 = alku2 + u"nen"
-##			if (wordform[-4] == u"i"):
-##				alku = wordform[:-4]    # Keltainen => keltanen.
-##				jatko = u"punainen"
-##			else:
-##				jatko = u"hevoinen"
-##			print (u"Keltainen " + wordform + u" " + alku + u" " + jatko)
-		elif (jatko in [u"asiakas", u"avokas"]):
-			jatko = u"iäkäs"
-		elif (jatko == u"varas"):
-			jatko = u"vilkas"
-		elif ((jatko == u"vieras") and (d != None) and (d['utelias_ankerias'] != None)):
-			jatko = u"utelias"
+#			if (wordform[-4] == u"i"):
+#				alku = wordform[:-4]    # Keltainen => keltanen.
+#				jatko = u"punainen"
+#			else:
+#				jatko = u"hevoinen"
+####			print (u"Keltainen " + wordform + u" " + alku + u" " + jatko)
 		#
 		# Korjataan alku- ja jatko-kenttien arvoja.
 		#
 		elif (jatko == u"rakentaa"):
+#		if (jatko == u"rakentaa"):
 			alku = wordform[:-4]
-		elif ((nsyl > 2) and (jatko == u"vastaus") and
-		      (rx != None) and (d != None) and ((d['aivoitus'] != None) or (d['jaotus'] != None))):
-			#
-			# Aivoitus => aivotus. Jaotus => jaoitus.
-			#
-			if (d['aivoitus'] != None):
-				alku2 = wordform[:-4] + wordform[-3:-1]           # Aivoitus => aivotus.
-			else:
-				alku2 = wordform[:-3] + u"i" + wordform[-3:-1]    # Jaotus => jaoitus.
-			jatko2 = jatko
-			wordform2 = alku2 + wordform[-1:]
-#			print(u"J " + wordform2 + u" " + alku2 + u" " + s + u"\n")
-		elif ((nsyl > 3) and (jatko == u"autio") and
-		      (rx != None) and (d != None) and ((d['obligaatio'] != None) or (d['resoluutio'] != None))):
-			#
-			# Obligaatio => obligatsioni, obligatsiooni, obligatio, obligationi, obligatiooni.
-			# Revoluutio => revolutsioni, revolutsiooni, revolutio, revolutioni, revolutiooni.
-			# Tässä -ni ei ole omistusliite.
-			#
-			alku2 = wordform[:-4] + u"tsion"      # Obligatsioni, revolutsioni.
-			jatko2 = u"paperi"
-			wordform2 = alku2 + u"i"
-				
-			alku3 = wordform[:-4] + u"tsioon"     # Obligatsiooni, revolutsiooni.
-			jatko3 = u"paperi"
-			wordform3 = alku3 + u"i"
-			
-			alku4 = wordform[:-4] + wordform[-3:] # Obligatio, revolutio.
-			jatko4 = jatko
-			wordform4 = alku4
-			
-			alku5 = alku4 + u"n"                  # Obligationi, revolutioni.
-			jatko5 = u"paperi"
-			wordform5 = alku5 + u"i"
-			
-			alku6 = alku4 + u"on"                 # Obligatiooni, revolutiooni.
-			jatko6 = u"paperi"
-			wordform6 = alku6 + u"i"
-       		elif ((nsyl > 3) and (jatko == u"autio") and
-		      (rx != None) and (d != None) and (d['illuusio'] != None)):
-			#
-			# Illuusio => illusioni, illusiooni, illusio.
-			#
-			alku2 = wordform[:-4] + u"sion"     # Illusioni.
-			jatko2 = u"paperi"
-			wordform2 = alku2 + u"i"
 
-			alku3 = wordform[:-4] + u"sioon"    # Illusiooni.
-			jatko3 = u"paperi"
-			wordform3 = alku3 + u"i"
-
-			alku4 = wordform[:-4] + u"sio"      # Illusio.
-			jatko4 = jatko
-			wordform4 = alku4
-		elif ((nsyl > 2) and (jatko == u"autio") and
-		      (rx != None) and (d != None) and ((d['traditio'] != None) or (d['funktio'] != None))):
-			#
-			# Traditio => traditsioni, traditsiooni, traditsio.
-			#
-			alku2 = wordform[:-2] + u"sion"    # Traditsioni, funktsioni.
-			jatko2 = u"paperi"
-			wordform2 = alku2 + u"i"
-
-			alku3 = wordform[:-2] + u"sioon"   # Traditsiooni, funktsiooni.
-			jatko3 = u"paperi"
-			wordform3 = alku2 + u"i"
-			
-			alku4 = wordform[:-2] + u"sio"      # Traditsio, funktsio.
-			jatko4 = jatko
-			wordform4 = alku4
-		elif ((nsyl > 2) and (rx != None) and (d != None) and (d['symboli_ym'] != None) and
-		      (malaga_word_class in [u"nimisana", u"nimi_laatusana", u"laatusana"])):
-			#
-			# Symboli => symbooli, atoomi, uniooni, tenoori, alkoovi, aploodi,
-			# pedagoogi, psykoloogi, filosoofi, katastroofi, mutta ei esim. koni => kooni.
-			#
-			alku2 = wordform[:-2] + u"o" + wordform[-2]
-			jatko2 = jatko
-			wordform2 = alku2 + u"i"
-		elif ((nsyl > 2) and (rx != None) and (d != None) and (d['balladi'] != None)):
-			#
-			# Balladi => ballaadi.
-			#
-			alku2 = wordform[:-2] + u"a" + wordform[-2]
-			jatko2 = jatko
-			wordform2 = alku2 + u"i"
-		elif ((nsyl > 2) and (rx != None) and (d != None) and (d['logia_ym'] != None) and
-		      (malaga_word_class in [u"nimisana", u"nimi_laatusana"])):
-			#
-			# Pedagogia => pedagoogia, psykolo(o)gia, filoso(o)fia.
-			#
-			alku2 = wordform[:-3] + u"o" + wordform[-3:-1]
-			jatko2 = jatko
-			wordform2 = alku2 + u"a"
-		elif ((nsyl > 2) and (rx != None) and (d != None) and (d['loginen_ym'] != None) and
-		      (malaga_word_class in [u"nimisana", u"nimi_laatusana"])):
-			#
-			# Pedagoginen => pedagooginen, psykolo(o)ginen, filoso(o)finen.
-			#
-			alku2 = wordform[:-5] + u"o" + wordform[-5:-3]
-			jatko2 = jatko
-			wordform2 = alku2 + u"nen"
-		elif ((nsyl > 2) and (rx != None) and (d != None) and (d['grafia'] != None)):
-			#
-			# Topografia => topograafia.
-			#
-			alku2 = wordform[:-3] + u"a" + wordform[-3:-1]
-			jatko2 = jatko
-			wordform2 = alku2 + u"a"
-		elif ((nsyl > 2) and (rx != None) and (d != None) and (d['grafinen'] != None)):
-			#
-			# Topografinen => topograafinen.
-			#
-			alku2 = wordform[:-5] + u"a" + wordform[-5:-3]
-			jatko2 = jatko
-			wordform2 = alku2 + u"nen"
-		elif ((rx != None) and (d != None) and (d['ironinen_ym'] != None) and
-		      (malaga_word_class in [u"nimisana", u"nimi_laatusana", u"laatusana"])):
-			#
-			# Ironinen => irooninen, allegorinen => allegoorinen.
-			#
-			alku2 = wordform[:-5] + u"o" + wordform[-5:-3]
-			jatko2 = jatko
-			wordform2 = alku2 + u"nen"
-#			print (u"Ironinen " + wordform2 + u" " + alku2 + u" " + jatko2)
-		elif ((rx != None) and (d != None) and (d['psyykkinen_ym'] != None) and
-		      (malaga_word_class in [u"nimisana", u"nimi_laatusana", u"laatusana"]) and
-		      (wordform != "eettinen")):  # "Eetillinen" on Joukahaisessa.
-			#
-			# Psyykkinen => psyykillinen, eeppinen => eepillinen, kriittinen => kriitillinen.
-			#
-			alku2 = wordform[:-5] + u"illi"
-			jatko2 = jatko
-			wordform2 = alku2 + u"nen"
-		elif ((rx != None) and (d != None) and (d['relatiivinen'] != None)):
-			#
-			# Relatiivinen => relativinen.
-			#
-			alku2 = wordform[:-6] + u"vi"
-			jatko2 = jatko
-			wordform2 = alku2 + u"nen"
-		elif ((rx != None) and (d != None) and (d['aarteisto'] != None)):
-			#
-			# Aarteisto => aartehisto.
-			#
-			alku2 = wordform[:-4] + u"h" + wordform[-4:]
-			jatko2 = jatko
-			wordform2 = alku2
-#			print (u"Aarteisto " + wordform2 + u" " + alku2 + u" " + jatko2)
-		elif ((jatko == u"iäkäs") and (malaga_word_class in [u"nimi_laatusana", u"laatusana"])):
-			#
-			# Iäkäs => iäkkäisyys.
-			#
-			if (wordform[-2] == u"a"):
-				alku2 = alku + u"kaisuu";
-			else:
-				alku2 = alku + u"käisyy";
-			jatko2 = u"kalleus"
-			wordform2 = alku2 + u"s"
-
-			if ((nsyl == 3) and (rx != None) and (d != None) and (d['maineikas'] != None)):
-				#
-				# Maineikas => mainehikas.
-				#
-				alku3 = wordform[:-4] + u"hik"
-				wordform3 = alku3 + wordform[-2:]
-				jatko3 = jatko
-#				print ("Huuhaa " + wordform + u" " + wordform3 + u" " + alku3 + u"\n");
-		
 		# Tulostetaan.
 
 #		print(u"Word   " + wordform + u"\n")
