@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2007 Harri Pitkänen (hatapitk@iki.fi)
+# Copyright 2007 - 2008 Harri Pitkänen (hatapitk@iki.fi)
 # Program to generate lexicon files for Suomi-malaga Voikko edition
 
 # This program is free software; you can redistribute it and/or modify
@@ -30,43 +30,44 @@ import codecs
 
 flag_attributes = voikkoutils.readFlagAttributes(generate_lex_common.VOCABULARY_DATA + u"/flags.txt")
 
+# Get command line options
+OPTIONS = generate_lex_common.get_options()
+
+# According to the options, remove some special vocabularies
+old_special = generate_lex_common.SPECIAL_VOCABULARY
+generate_lex_common.SPECIAL_VOCABULARY = []
+for s in old_special:
+	if s[0] != "usage": continue
+	if s[1] in OPTIONS["extra-usage"]: continue
+	generate_lex_common.SPECIAL_VOCABULARY.append(s)
+
 main_vocabulary = generate_lex_common.open_lex(VOIKKO_LEX_DIR, "joukahainen.lex")
 vocabulary_files = {}
 for voc in generate_lex_common.SPECIAL_VOCABULARY:
 	vocabulary_files[voc[2]] = generate_lex_common.open_lex(VOIKKO_LEX_DIR, voc[2])
 
-# Get the minimal frequency of words to be included
-MIN_FREQUENCY = 9
-if len(sys.argv) > 1: MIN_FREQUENCY = int(sys.argv[1])
 
 def frequency(word):
 	fclass = word.getElementsByTagName("fclass")
 	if len(fclass) == 0: return 7
 	return int(generate_lex_common.tValue(fclass[0]))
 
-
-# Writes the vocabulary entry to a suitable file
-def write_entry(word, entry):
-	global vocabulary_files
-	global main_vocabulary
-	special = False
-	for voc in generate_lex_common.SPECIAL_VOCABULARY:
-		group = word.getElementsByTagName(voc[0])
-		if len(group) == 0: continue
-		if generate_lex_common.has_flag(group[0], voc[1]):
-			vocabulary_files[voc[2]].write(entry + u"\n")
-			special = True
-	if not special:
-		main_vocabulary.write(entry + u"\n")
+# Check the style flags of the word according to current options.
+# Returns True if the word is acceptable, otherwise returns false.
+def check_style(word):
+	global OPTIONS
+	for styleE in word.getElementsByTagName("style"):
+		for style in generate_lex_common.tValues(styleE, "flag"):
+			if not style in OPTIONS["style"]: return False
+	return True
 
 def handle_word(word):
-	global MIN_FREQUENCY
+	global OPTIONS
 	# Drop words that are not needed in the Voikko lexicon
 	if generate_lex_common.has_flag(word, "not_voikko"): return
-	if generate_lex_common.has_flag(word, "incorrect"): return
-	if generate_lex_common.has_flag(word, "dialect"): return
-	if frequency(word) >= MIN_FREQUENCY + 1: return
-	if frequency(word) == MIN_FREQUENCY and generate_lex_common.has_flag(word, "confusing"): return
+	if not check_style(word): return
+	if frequency(word) >= OPTIONS["frequency"] + 1: return
+	if frequency(word) == OPTIONS["frequency"] and generate_lex_common.has_flag(word, "confusing"): return
 	
 	# Get the inflection class. Exactly one inflection class is needed
 	voikko_infclass = None
@@ -88,6 +89,11 @@ def handle_word(word):
 	# Get forced vowel type
 	forced_inflection_vtype = generate_lex_common.vowel_type(word.getElementsByTagName("inflection")[0])
 	
+	# Construct debug information
+	debug_info = u""
+	if OPTIONS["debug"]:
+		debug_info = u', sourceid: "%s"' % word.documentElement.getAttribute("id")
+	
 	# Process all alternative forms
 	for altform in generate_lex_common.tValues(word.getElementsByTagName("forms")[0], "form"):
 		wordform = altform.replace(u'|', u'').replace(u'=', u'')
@@ -100,13 +106,17 @@ def handle_word(word):
 		elif vtype == voikkoutils.VOWEL_BOTH: malaga_vtype = u'aä'
 		rakenne = generate_lex_common.get_structure(altform, malaga_word_class)
 		if alku == None:
-			write_entry(word, u"#Malaga class not found for (%s, %s)\n" \
-			            % (wordform, voikko_infclass))
+			errorstr = u"#Malaga class not found for (%s, %s)\n" \
+				% (wordform, voikko_infclass)
+			generate_lex_common.write_entry(main_vocabulary, vocabulary_files,
+				word, errorstr)
+			print(errorstr)
 			continue
-		entry = u'[perusmuoto: "%s", alku: "%s", luokka: %s, jatko: <%s>, äs: %s%s%s];' \
+		entry = u'[perusmuoto: "%s", alku: "%s", luokka: %s, jatko: <%s>, äs: %s%s%s%s];' \
 		          % (wordform, alku, malaga_word_class, jatko, malaga_vtype, malaga_flags,
-				   generate_lex_common.get_structure(altform, malaga_word_class))
-		write_entry(word, entry)
+			   generate_lex_common.get_structure(altform, malaga_word_class),
+			   debug_info)
+		generate_lex_common.write_entry(main_vocabulary, vocabulary_files, word, entry)
 
 
 voikkoutils.process_wordlist(generate_lex_common.VOCABULARY_DATA + u'/joukahainen.xml', \
